@@ -14,22 +14,22 @@ $LastChangedRevision$
 
 =item Release Version
 
-1.8.8
+1.8.9
 
 =cut
 
 # Set the Version Number.
 BEGIN {
-    our $VERSION = '1.8.8';
+    our $VERSION = '1.8.9';
 }
 
 =item Date
 
-$LastChangedDate: 2005-10-26 15:38:36 -0700 (Wed, 26 Oct 2005) $
+$LastChangedDate: 2005-10-28 19:41:36 -0700 (Fri, 28 Oct 2005) $
 
 =item Subversion ID
 
-$Id: Bric.pm 6870 2005-10-26 22:38:36Z theory $
+$Id: Bric.pm 6895 2005-10-29 02:41:36Z theory $
 
 =back
 
