@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-13 21:03:08 -0700 (Wed, 13 Jul 2005) $
+$LastChangedDate: 2006-01-16 12:29:31 -0800 (Mon, 16 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -1072,7 +1072,9 @@ NONE
 
 sub needs_publish {
     my $self = shift;
-    return $self->get_current_version == $self->get_published_version ? 0 : 1;
+    # Version 0 is never published. Neither is undef, of course.
+    my $pub_version = $self->get_published_version or return 1;
+    return $self->get_current_version == $pub_version ? 0 : 1;
 }
 
 ################################################################################
