@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-10-20 11:15:30 -0700 (Thu, 20 Oct 2005) $
+$LastChangedDate: 2006-01-18 11:24:10 -0800 (Wed, 18 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,19 @@ use constant DEFAULT_ORDER => 'cover_date';
 
 #--------------------------------------#
 # Private Class Fields
-my ($meths, @ord);
+my ($meths, @ord, $ESCAPE_URI);
+
+BEGIN{
+    if ($ENV{MOD_PERL}) {
+        require Apache::Util;
+        rethrow_exception($@) if $@;
+        $ESCAPE_URI = \&Apache::Util::escape_uri;
+    } else {
+        require URI::Escape;
+        rethrow_exception($@) if $@;
+        $ESCAPE_URI = \&URI::Escape::uri_escape;
+    }
+}
 
 #--------------------------------------#
 # Instance Fields
@@ -367,6 +379,7 @@ BEGIN {
                          _category_obj   => Bric::FIELD_NONE,
                          _file           => Bric::FIELD_NONE,
                          _media_type_obj => Bric::FIELD_NONE,
+                         _upload_data    => Bric::FIELD_NONE,
                         });
 }
 
@@ -1042,7 +1055,7 @@ sub my_meths {
         push @ord, $meth->{name};
     }
 
-    push @ord, qw(file_name category category_name), pop @ord;
+    push @ord, qw(file_name), pop @ord;
     $meths->{file_name} = {
                            get_meth => sub { shift->get_file_name(@_) },
                            get_args => [],
@@ -1056,25 +1069,6 @@ sub my_meths {
                                          maxlength => 256
                                        }
                           };
-    $meths->{category} = {
-                          get_meth => sub { shift->get_category_object(@_) },
-                          get_args => [],
-                          name     => 'category',
-                          disp     => 'Category',
-                          len      => 64,
-                          req      => 1,
-                          type     => 'short',
-                         };
-
-    $meths->{category_name} = {
-                          get_meth => sub { shift->get_category_object(@_)->get_name },
-                          get_args => [],
-                          name     => 'category_name',
-                          disp     => 'Category Name',
-                          len      => 64,
-                          req      => 1,
-                          type     => 'short',
-                         };
 
     # Copy the data for the title from name.
     $meths->{title} = { %{ $meths->{name} } };
@@ -1365,8 +1359,10 @@ B<Notes:> NONE.
 sub get_local_uri {
     my $self = shift;
     my $loc = $self->get_location || return;
-    return Bric::Util::Trans::FS->cat_uri(MEDIA_URI_ROOT,
-                                        Bric::Util::Trans::FS->dir_to_uri($loc) );
+    return Bric::Util::Trans::FS->cat_uri(
+        MEDIA_URI_ROOT,
+        Bric::Util::Trans::FS->dir_to_uri($loc),
+    );
 }
 
 =item $uri = $media->get_path()
@@ -1438,17 +1434,24 @@ B<Notes:> NONE.
 =cut
 
 sub upload_file {
-    my ($self, $fh, $name, $type, $size) = @_;
+    my $self = shift;
 
-    my ($id, $v, $old_fn, $loc, $uri) =
-      $self->_get(qw(id version file_name location uri));
+    my ($id, $v) = $self->_get(qw(id version));
+
+    unless ($id) {
+        # If there is no ID, we're not ready to create a file name, yet.
+        $self->_set(['_upload_data'] => [\@_]);
+        return $self;
+    }
+
+    my ($fh, $name, $type, $size) = @_;
     my @id_dirs = $id =~ /(\d\d?)/g;
     my $dir = Bric::Util::Trans::FS->cat_dir(MEDIA_FILE_ROOT, @id_dirs, "v.$v");
     Bric::Util::Trans::FS->mk_path($dir);
     my $path = Bric::Util::Trans::FS->cat_dir($dir, $name);
 
-    open FILE, ">$path"
-      or throw_gen(error => "Unable to open '$path': $!");
+    local *FILE;
+    open FILE, ">$path" or throw_gen "Unable to open '$path': $!";
     my $buffer;
     while (read($fh, $buffer, 10240)) { print FILE $buffer }
     close $fh;
@@ -1476,20 +1479,14 @@ sub upload_file {
     my $oc_obj = $self->get_primary_oc;
 
     my $new_loc = Bric::Util::Trans::FS->cat_dir('/', @id_dirs, "v.$v", $name);
-
     # Set the location, name, and URI.
-    if (not defined $old_fn
-        or not defined $uri
-        or $old_fn ne $name
-        or $loc ne $new_loc) {
-        $self->_set(['file_name'], [$name]);
-        $uri = Bric::Util::Trans::FS->cat_uri
-          ($self->_construct_uri($self->get_category_object, $oc_obj),
-           $oc_obj->get_filename($self));
+    $self->_set(['file_name'], [$name]);
+    my $uri = Bric::Util::Trans::FS->cat_uri(
+        $self->_construct_uri($self->get_category_object, $oc_obj),
+        $ESCAPE_URI->($oc_obj->get_filename($self))
+    );
 
-        $self->_set([qw(location  uri   _update_uri)] =>
-                    [   $new_loc, $uri, 1]);
-    }
+    $self->_set( [qw(location uri _update_uri)] => [ $new_loc, $uri, 1 ] );
 
     if (my $auto_fields = $self->_get_auto_fields) {
         # We need to autopopulate data field values. Get the top level element
@@ -1756,6 +1753,13 @@ sub save {
             } else {
                 $self->_insert_media();
                 $self->_insert_instance();
+                if (my $upload_data = $self->_get('_upload_data')) {
+                    # Ah, we need to handle a file upload.
+                    $self->upload_file(@$upload_data);
+                    $self->_set(['_upload_data'] => [undef]);
+                    # Update to save the file location data.
+                    $self->_update_instance;
+                }
             }
         }
 
