@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-10-07 11:27:15 -0700 (Fri, 07 Oct 2005) $
+$LastChangedDate: 2006-01-16 14:46:16 -0800 (Mon, 16 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -1110,7 +1110,7 @@ sub my_meths {
         $meths->{$meth->{name}} = $meth;
         push @ord, $meth->{name};
     }
-    push @ord, qw(slug category category_name), pop @ord;
+    push @ord, qw(slug), pop @ord;
     $meths->{slug}    = {
                           get_meth => sub { shift->get_slug(@_) },
                           get_args => [],
@@ -1126,27 +1126,6 @@ sub my_meths {
                                           maxlength => 64
                                       }
                          };
-    $meths->{category} = {
-                          get_meth => sub { shift->get_primary_category(@_) },
-                          get_args => [],
-                          set_meth => sub { shift->set_primary_category(@_) },
-                          set_args => [],
-                          name     => 'category',
-                          disp     => 'Category',
-                          len      => 64,
-                          req      => 1,
-                          type     => 'short',
-                         };
-
-    $meths->{category_name} = {
-                          get_meth => sub { shift->get_primary_category(@_)->get_name },
-                          get_args => [],
-                          name     => 'category_name',
-                          disp     => 'Category Name',
-                          len      => 64,
-                          req      => 1,
-                          type     => 'short',
-                         };
 
     # Rename element, too.
     $meths->{element} = { %{ $meths->{element} } };
