@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-08-23 16:23:46 -0700 (Tue, 23 Aug 2005) $
+$LastChangedDate: 2006-01-16 14:46:16 -0800 (Mon, 16 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -1164,6 +1164,16 @@ sub my_meths {
                           type     => 'short',
                          };
 
+    $meths->{category_uri} = {
+                          get_meth => sub { shift->get_category(@_)->get_uri },
+                          get_args => [],
+                          name     => 'category_uri',
+                          disp     => 'Category URI',
+                          len      => 64,
+                          req      => 1,
+                          type     => 'short',
+                         };
+
     return !$ord ? $meths : wantarray ? @{$meths}{@ord} : [@{$meths}{@ord}];
 }
 
@@ -1310,16 +1320,7 @@ This is really the deploy date
 
 =cut
 
-sub set_publish_status {
-    my $self = shift;
-    my ($status) = @_;
-
-    if ($status ne $self->get_deploy_status) {
-        $self->set_deploy_status($status);
-    }
-
-    return $self;
-}
+sub set_publish_status { $_[0]->set_deploy_status($_[1]) }
 
 ################################################################################
 
