@@ -52,7 +52,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-14 17:55:18 -0700 (Thu, 14 Jul 2005) $
+$LastChangedDate: 2005-11-03 15:10:57 -0800 (Thu, 03 Nov 2005) $
 
 =head1 SYNOPSIS
 
@@ -695,6 +695,8 @@ sub load_asset {
         $init{name}     = $mdata->{name};
 
         # mix in dates
+        $mdata->{publish_date} ||= $mdata->{first_publish_date}
+            if $mdata->{first_publish_date};
         for my $name qw(cover_date expire_date publish_date first_publish_date) {
             my $date = $mdata->{$name};
             next unless $date; # skip missing date
