@@ -56,7 +56,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-10 21:05:35 -0700 (Sun, 10 Jul 2005) $
+$LastChangedDate: 2005-11-03 15:10:23 -0800 (Thu, 03 Nov 2005) $
 
 =head1 SYNOPSIS
 
@@ -907,6 +907,8 @@ sub load_asset {
         $story->set_publish_status($sdata->{publish_status}) if $update;
 
         # assign dates
+        $sdata->{publish_date} ||= $sdata->{first_publish_date}
+            if $sdata->{first_publish_date};
         for my $name qw(cover_date expire_date publish_date first_publish_date) {
             my $date = $sdata->{$name};
             next unless $date; # skip missing date
