@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-10-26 16:58:52 -0700 (Wed, 26 Oct 2005) $
+$LastChangedDate: 2006-01-17 08:52:20 -0800 (Tue, 17 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -1023,6 +1023,7 @@ sub publish {
     my ($ats, $oc_sts) = ({}, {});
     my ($ba, $key, $user_id, $publish_date, $die_err) = @_;
     my $published = 0;
+    $publish_date ||= strfdate;
     $ba->set_publish_date($publish_date);
     my $baid = $ba->get_id;
 
@@ -1156,8 +1157,8 @@ sub publish {
         $ba->set_publish_status(1);
         # Set published version if we've reverted
         # (i.e. unless we're republishing published_version)
-        my $pubversion = $ba->get_published_version || 0;
-        if ($ba->get_version > $pubversion) {
+        my $pubversion = $ba->get_published_version;
+        unless (defined $pubversion && $ba->get_version <= $pubversion) {
             $ba->set_published_version($ba->get_version);
         }
         # Now log that we've published and get it out of workflow.
@@ -1235,7 +1236,8 @@ sub publish_another {
 
     # Figure out the publish time. Default to the same time as the story
     # that's currently being burned.
-    $pub_time ||= $self->get_story->get_publish_date(ISO_8601_FORMAT);
+    $pub_time ||= $self->get_story->get_publish_date(ISO_8601_FORMAT)
+        || strfdate;
 
     if ($pub_time gt strfdate) {
         # Schedule it to be published later.
@@ -1259,13 +1261,16 @@ sub publish_another {
 
 =item @resources = $burner->burn_one($ba, $oc, $cat);
 
-Publishes an asset. Returns a list of resources burned. Parameters are:
+Burn an asset in a given output channel and category, this is usually called by
+the preview or publish method. Returns a list of resources burned. 
+
+Parameters are:
 
 =over 4
 
 =item C<$ba>
 
-A business asset object to publish.
+A business asset object to burn.
 
 =item C<$oc>
 
