@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-24 11:09:36 -0700 (Sun, 24 Jul 2005) $
+$LastChangedDate: 2006-01-17 08:52:20 -0800 (Tue, 17 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,7 @@ $LastChangedDate: 2005-07-24 11:09:36 -0700 (Sun, 24 Jul 2005) $
   $template_burner = Bric::Util::Burner::Template->new($burner);
 
   # burn an asset, get back a list of resources
-  @resources = $template_burner->burn_one($ba, $at, $oc, $cat);
+  @resources = $template_burner->burn_one($ba, $oc, $cat, $at);
 
 =head1 DESCRIPTION
 
@@ -147,36 +147,31 @@ sub new {
 
 =over 4
 
-=item @resources = $template_burner->burn_one($ba, $at, $oc, $cat);
+=item @resources = $template_burner->burn_one($ba, $oc, $cat, $at);
 
-Publishes an asset. Returns a list of resources burned. Parameters are:
+Burn an asset in a given output channel and category, this is usually called by
+the preview or publish method. Returns a list of resources burned. 
+
+Parameters are:
 
 =over 4
 
-=item *
+=item C<$ba>
 
-$ba
+A business asset object to burn.
 
-A business asset object to publish.
+=item C<$oc>
 
-=item *
+The output channel to which to burn the asset.
 
-$at
+=item C<$cat>
+
+A category in which to burn the asset.
+
+=item C<$at>
 
 A asset type object for $ba
 
-=item *
-
-$oc
-
-An output channel object to use for the publish
-
-=item *
-
-$category
-
-A category in which to publish.
-
 =back
 
 B<Throws:>
