@@ -15,7 +15,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-07-22 17:36:19 -0700 (Fri, 22 Jul 2005) $
+$LastChangedDate: 2006-01-17 08:52:20 -0800 (Tue, 17 Jan 2006) $
 
 =head1 SYNOPSIS
 
@@ -25,7 +25,7 @@ $LastChangedDate: 2005-07-22 17:36:19 -0700 (Fri, 22 Jul 2005) $
  $tt_burner = Bric::Util::Burner::TemplateToolkit->new($burner);
 
  # Burn an asset, get back a list of resources
- @resources = $tt_burner->burn_one($ba, $at, $oc, $cat);
+ @resources = $tt_burner->burn_one($ba, $oc, $cat, $at);
 
 =head1 DESCRIPTION
 
@@ -156,35 +156,31 @@ sub new {
 
 #------------------------------------------------------------------------------#
 
-=item @resources = $b->burn_one($ba, $at, $oc, $cat);
+=item @resources = $b->burn_one($ba, $oc, $cat, $at);
 
-Publishes an asset.  Returns a list of resources burned.  Parameters are:
+Burn an asset in a given output channel and category, this is usually called by
+the preview or publish method. Returns a list of resources burned. 
+
+Parameters are:
 
 =over 4
 
-=item *
+=item C<$ba>
 
-$ba
+A business asset object to burn.
 
-A business asset object to publish.
+=item C<$oc>
 
-=item *
+The output channel to which to burn the asset.
 
-$at
+=item C<$cat>
 
-A asset type object for $ba
+A category in which to burn the asset.
 
-=item *
+=item C<$at>
 
-$oc
-
-An output channel object to use for the publish
-
-=item *
-
-cat
-
-A category in which to publish.
+A asset type object for $ba.
+Note that this is not currently used by the TT burner
 
 =back
 
