@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-03-06 13:05:30 -0800 (Sun, 06 Mar 2005) $
+$LastChangedDate: 2005-11-28 16:01:14 -0800 (Mon, 28 Nov 2005) $
 
 =head1 SYNOPSIS
 
@@ -732,6 +732,8 @@ To Translate:
   'You do not have permission to auto-publish story "[_1]"' => 'You do not have permission to auto-publish story "[_1]"',
   'You do not have permission to auto-publish media "[_1]"' => 'You do not have permission to auto-publish media "[_1]"',
   'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".' => 'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".',
+  '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
+  '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
 
 =end comment
 
