@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2004-11-11 10:44:32 -0800 (Thu, 11 Nov 2004) $
+$LastChangedDate: 2005-11-28 16:01:14 -0800 (Mon, 28 Nov 2005) $
 
 =head1 SYNOPSIS
 
@@ -41,8 +41,10 @@ our %Lexicon = (
   '[quant,_1,Alert] acknowledged.' => '[quant,_1,Alert,Alerts] acknowledged.',
   '[quant,_1,Contributor] "[_2]" associated.' => '[quant,_1,Contributor,Contributors] "[_2]" assocuated.',
   '[quant,_1,Template] deployed.' => '[quant,_1,Template,Templates] deployed.',
-  '[quant,_1,media,media] published.' => '[quant,_1,media,media] published',
-  '[quant,_1,story,stories] published.' => '[quant,_1,story,stories] published',
+  '[quant,_1,media,media] published.' => '[quant,_1,media,media] published.',
+  '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
+  '[quant,_1,story,stories] published.' => '[quant,_1,story,stories] published.',
+  '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
  _AUTO => 1
 );
 
