@@ -16,7 +16,7 @@ require Bric; our $VERSION = Bric->VERSION;
 
 =head1 DATE
 
-$LastChangedDate: 2005-03-06 13:05:30 -0800 (Sun, 06 Mar 2005) $
+$LastChangedDate: 2005-11-28 16:01:14 -0800 (Mon, 28 Nov 2005) $
 
 =head1 SYNOPSIS
 
@@ -482,8 +482,6 @@ To translate:
   'Associate'
   'Preview in'
   'Parent cannot choose itself or its child as its parent. Try a different parent.'
-  '[quant,_1,story,stories] published.'
-  '[quant,_1,media,media] published.'
   'Category URI'
   'Story "[_1]" saved and shelved.'
   'Story "[_1]" created and saved.'
@@ -546,6 +544,10 @@ To translate:
   'Cannot auto-publish related $rel_disp_name "[_1]" because it is not on a publish desk.' => 'Cannot auto-publish related $rel_disp_name "[_1]" because it is not on a publish desk.'
   'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.' => 'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.'
   'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".' => 'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".',
+  '[quant,_1,media,media] published.' => '[quant,_1,media,media] published.',
+  '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
+  '[quant,_1,story,stories] published.' => '[quant,_1,story,stories] published.',
+  '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
 
 =end comment
 
