@@ -716,6 +716,8 @@ To translate:
   '[_1] Site [_2] Permissions' => '[_1] Site [_2] Permissions', # Site Category Permissions
   'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.' => 'The URI "[_1]" is not unique. Please change the cover date, output channels, slug, or categories as necessary to make the URIs unique.'
   'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".' => 'Name "[_1]" is not a valid media name. The name must be of the form "type/subtype".',
+  '[quant,_1,media,media] expired.' => '[quant,_1,media,media] expired.',
+  '[quant,_1,story,stories] expired.' => '[quant,_1,story,stories] expired.',
 
 =end comment
 
